# pic_resizer

A image resizing tool.

[![PyPI version](https://badge.fury.io/py/pic-resizer.svg)](https://badge.fury.io/py/pic-resizer)


## Installation

```bash
pip install pic_resizer
```

## Usage

```console
~ ➜ pic_resizer --help
Usage: pic_resizer [OPTIONS] COMMAND [ARGS]...

Options:
  --version  Show the version and exit.
  --help     Show this message and exit.

Commands:
  cli  Operating from the command line
  web  Operating in the web app
```

### cli

[![asciicast](https://asciinema.org/a/d5G7DaIrDN048rrLGr1TbJDh1.svg)](https://asciinema.org/a/d5G7DaIrDN048rrLGr1TbJDh1)

### web

![](https://s3.bmp.ovh/imgs/2022/08/09/1d0c289413d7078e.png)
